@@ -317,6 +317,7 @@ sub prep {
 		my $line=<$changelog>;
 		if ($line=~/^[^ ]+\s+\(([^)]+)\)\s/) {
 			my $version=$1;
+			$version=~s/\s+//; # ensure no whitespace
 			if ($version=~/(.*)-(.*)/) {
 				$version=$1;
 				$this->release($2);
@@ -490,10 +491,14 @@ sub build {
 
 	chdir $this->unpacked_tree;
 	my $log=$this->runpipe(1, "debian/rules binary 2>&1");
-	if ($?) {
+	chdir "..";
+	my $err=$?;
+	if ($err) {
+		if (! defined $log) {
+			die "Package build failed; could not run generated debian/rules file.\n";
+		}
 		die "Package build failed. Here's the log:\n", $log;
 	}
-	chdir "..";
 
 	return $this->name."_".$this->version."-".$this->release."_".$this->arch.".deb";
 }
@@ -683,7 +688,7 @@ sub email {
 		close MAILNAME;
 	}
 	if (!$mailname) {
-		$mailname=$this->runpipe(1, "hostname -f");
+		$mailname=$this->runpipe(1, "hostname");
 		chomp $mailname;
 	}
 	return "$login\@$mailname";
@@ -738,7 +743,7 @@ sub postinst {
 	return $postinst unless %$owninfo;
 	
 	my ($firstline, $rest)=split(/\n/, $postinst, 2);
-	if ($firstline !~ m/^#!\s*\/bin\/sh/) {
+	if ($firstline !~ m/^#!\s*\/bin\/(ba)?sh/) {
 		print STDERR "warning: unable to add ownership fixup code to postinst as the postinst is not a shell script!\n";
 		return $postinst;
 	}
@@ -754,7 +759,7 @@ sub postinst {
 	return "$firstline\n$permscript\n$rest";
 }
 
-=cut
+=back
 
 =head1 AUTHOR
 
